==> mysql-8.0_8.0.45.orig.tar.gz: mysql-8.0.45/router/src/harness/include/mysql/harness/tls_types.h <==
/*
  Copyright (c) 2021, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQL_HARNESS_TLS_TYPES_INCLUDED
#define MYSQL_HARNESS_TLS_TYPES_INCLUDED

#ifdef _WIN32
// include winsock2.h before openssl/ssl.h
#include <windows.h>
#include <winsock2.h>
#include <ws2tcpip.h>
#endif

#include <memory>

#include <openssl/ssl.h>

namespace mysql_harness {
namespace impl {
class Deleter_SSL {
 public:
  void operator()(SSL *v) { SSL_free(v); }
};
}  // namespace impl

using Ssl = std::unique_ptr<SSL, mysql_harness::impl::Deleter_SSL>;

}  // namespace mysql_harness

#endif

==> mysql-8.0.32.tar.gz: mysql-8.0.32/router/src/harness/include/mysql/harness/tls_types.h <==
/*
  Copyright (c) 2021, 2022, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQL_HARNESS_TLS_TYPES_INCLUDED
#define MYSQL_HARNESS_TLS_TYPES_INCLUDED

#ifdef _WIN32
// include winsock2.h before openssl/ssl.h
#include <windows.h>
#include <winsock2.h>
#include <ws2tcpip.h>
#endif

#include <memory>

#include <openssl/ssl.h>

namespace mysql_harness {
namespace impl {
class Deleter_SSL {
 public:
  void operator()(SSL *v) { SSL_free(v); }
};
}  // namespace impl

using Ssl = std::unique_ptr<SSL, mysql_harness::impl::Deleter_SSL>;

}  // namespace mysql_harness

#endif
